#
# spec file for package geeqie
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           geeqie
Version:        2.4
Release:        1.6
Summary:        Lightweight Gtk+ based image viewer
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Viewers
URL:            http://www.geeqie.org
Source0:        https://github.com/BestImageViewer/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/BestImageViewer/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz.asc
Source2:        geeqie.keyring
BuildRequires:  c++_compiler
BuildRequires:  docbook_4
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  graphviz
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3-lxml
BuildRequires:  update-desktop-files
BuildRequires:  vim
BuildRequires:  yelp-tools
BuildRequires:  yelp-xsl
BuildRequires:  pkgconfig(champlain-0.12) >= 0.12
BuildRequires:  pkgconfig(champlain-gtk-0.12) >= 0.12
BuildRequires:  pkgconfig(ddjvuapi) >= 3.5.27
BuildRequires:  pkgconfig(exiv2) >= 0.11
BuildRequires:  pkgconfig(gspell-1)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.0.0
BuildRequires:  pkgconfig(lcms2) >= 2.0
BuildRequires:  pkgconfig(libarchive) >= 3.4.0
BuildRequires:  pkgconfig(libffmpegthumbnailer) >= 2.1.0
BuildRequires:  pkgconfig(libheif) >= 1.3.2
BuildRequires:  pkgconfig(libjxl) >= 0.3.7
BuildRequires:  pkgconfig(libopenjp2) >= 2.3.0
BuildRequires:  pkgconfig(libraw) >= 0.20
BuildRequires:  pkgconfig(libwebp) >= 0.6.1
BuildRequires:  pkgconfig(lua5.3)
BuildRequires:  pkgconfig(poppler-glib) >= 0.62
Requires(post): update-desktop-files
Requires(postun): update-desktop-files

%description
Geeqie is a lightweight image viewer for Linux, BSDs and compatibles.

%lang_package

%prep
%autosetup -p1

%build
%meson \
  -Dgq_helpdir=%{_docdir}/%{name} \
  -Dgq_htmldir=%{_docdir}/%{name} \
  -Dlua=disabled
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file org.geeqie.Geeqie
%fdupes %{buildroot}/%{_prefix}

# Already in the license directory
rm %{buildroot}%{_docdir}/%{name}/COPYING

%files
%license COPYING
%doc NEWS TODO README.md
%doc %{_docdir}/%{name}/html
%{_bindir}/geeqie
%{_datadir}/applications/org.geeqie.Geeqie.desktop
%{_datadir}/icons/hicolor/scalable/apps/geeqie.svg
%{_datadir}/geeqie/
%{_datadir}/pixmaps/geeqie.png
%{_datadir}/metainfo/org.geeqie.Geeqie.appdata.xml
%{_prefix}/lib/geeqie/
%{_mandir}/man1/geeqie.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Mon Mar 25 2024 ming li <mli@suse.com>
- Update to version 2.4:
  + Bug fixes (mainly packaging) and code improvements.
- Changes from version 2.3:
  + Bug fixes and code improvements.
- Drop geeqie-2.2-fix-filelist-crash.patch and
  geeqie-2.2-fix-rename-crash.patch: fixed upstream.
* Fri Mar  1 2024 Michael Vetter <mvetter@suse.com>
- boo#1220031:
  * Fix crash when hiding files gh/BestImageViewer/geeqie#1248
    Add geeqie-2.2-fix-filelist-crash.patch
  * Fix crash when renaming files gh/BestImageViewer/geeqie#1242
    Add geeqie-2.2-fix-rename-crash.patch
* Fri Jan 26 2024 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 2.2:
  + Enhanced debug output with -Ddevel=enabled option
  + Modify Collections user interface
  + Remote keyboard actions
  + Allow .desktop files to be linked to programmable mouse buttons
  + Option to show-hide selectable bars
  + On exit additional check for multiple windows open
  + Plugin to resize an image
  + Include a separator as a toolbar option
  + Change all .desktop files to RDNS style
  + GTK "Open With" feature menu option
  + Reduce the height of toolbars
  + Option to select "hamburger" menu style
  + More progress in GTK4 migration
  + Many bug fixes
- Remove exiv_0-28.patch, it's part of the release
* Wed Jul  5 2023 Marcel Kuehlhorn <tux93@opensuse.org>
- Add exiv_0-28.patch, fixing a bug with exiv2-0.28 and removing the
  version restriction
* Wed Jun 21 2023 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 2.1:
  + Additional --selection remote commands
  + Split view additional 3-image layout
  + Many bug fixes
  + Some progress in GTK4 migration
  + Change source code from c to c++
  + Much progress in making source code warning-free
  + Updated language support
- Remove 6c4226ff.patch and eb9d0e10.patch
  they are part of the release
- Disable LUA to work around gh#BestImageViewer/geeqie#1117
* Tue May  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Drop conditional set for pkgconfig(libraw) BuildRequires, fixes
  build for Leap 15.5.
* Tue Nov  8 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.0.1:
  + Exclude build directories from release tar.
- Add eb9d0e10.patch: Fix appdata and icon installation.
- Add 6c4226ff.patch: Fix appstream validation.
* Thu Sep  1 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 2.0
  + GTK2 no longer supported
  + Configuration system moved from Autotools to Meson
  + Spelling checks for metadata
  + When navigation folders, on return to a folder select last
    image viewed
  + Search facility in Exif window
  + Display keyboard shortcuts in popup menus
  + LIRC deleted
  + renderer-clutter() deleted
- Add new build requirement gspell for spell checking support
- Add new build requirement vim as the build needs xxd
- Remove no longer needed build requirements lirc-devel and clutter
- Replace build requirements libtool and intltool with meson
- Enable build requirements for ffmpegthumbnailer and libjxl
- Update the build requirement of lua to 5.3
* Fri May 27 2022 Stanislav Brabec <sbrabec@suse.com>
- Enable support for HEIF (bsc#1199987), JP2, RAW, WEBP, PDF.
- Enable support for opening archives.
- Build documentation.
- Update to version 1.7.3
  + Fix crash with Flatpak version
* Mon Jan 17 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.7.2
  + Copy image to clipboard option
  + Multi-threaded find duplicates
  + Generate sRGB thumbnails for images with embedded color profile
  + External image decoder option
  + Support jpeg xl format
  + Automated cache maintenance
  + Support archive (e.g. zip) files
  + Use system theme background color
  + Many small improvements
  + Many bug fixes
  + Updated language support
- Remove 0001-Fix-829-segfault-with-clutter-gtk.patch, merged upstream
- Append new developer GPG key to keyring
  https://www.freelists.org/post/geeqie/Huge-targz-and-missing-asc,3
* Sat Jan  9 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add upstream patch to fix crash with clutter-gtk (boo#1180228)
  + 0001-Fix-829-segfault-with-clutter-gtk.patch
* Thu Dec  3 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to version 1.6:
  + Support (excluding exif) for heic, webp, psd, cr3, jp2, djvu,
    svg
  + Load remote URLs
  + Save named window layouts
  + Save workspace layout
  + Export duplicates data to file
  + Search and Run command ("/" keystroke)
  + Tiff/pdf multi-page viewing
  + Show over/underexposed
  + Search for broken images
  + Show lens ID
  + File pane - filter by name or class
  + User definable status toolbar
  + Search by path
  + Search on collection
  + Find duplicates with same name but different content
  + User definable mouse buttons 8 and 9 (back/forward)
  + Folder pane list view - sort by name or date
  + Many small improvements
  + Many bug fixes
  + Updated translations.
- Removed geeqie-gcc10-buildfix.patch: Fixed upstream.
* Mon Sep 28 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Thu Jun  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add geeqie-gcc10-buildfix.patch: Fix build with gcc 10.
- Drop no longer needed desktop_database_post(un) calls from
  post(un), and various other spec modernizations.
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Fri Aug 23 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to version 1.5.1
  - #626 - High CPU load with animated GIFs
  - #683 - Build failuer on macOS
  - #686 - Zoom lable adjustment
  - #703 - non-glibc fix
  - Lua compatibility
* Wed Jul 31 2019 gutaper@gmail.com
- Update to version 1.5
- Drop exiv-2.0.27-buildfix.patch (fixed in upstream)
- Set CFLAGS="-Wno-deprecated-declarations" (Fix compilation fail)
* Mon Apr  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add exiv-2.0.27-buildfix.patch.
* Wed Nov  8 2017 gutaper@gmail.com
- Fix SLE_12 rpmlint warning "files-attr-not-set".
* Fri Sep  1 2017 zaitor@opensuse.org
- Enable pkgconfig(champlain-0.12), add
  pkgconfig(champlain-gtk-0.12), pkgconfig(clutter-1.0) and
  pkgconfig(clutter-gtk-1.0) BuildRequires and pass --enable-maps
  to configure: Build map support (boo#1054718).
- Enable conditional pkgconfig(lua5.1) BuildRequires and stop
  passing --disable-lua to configure: New lua is now in place in
  Tumbleweed, build lua support.
* Thu Jul 27 2017 tchvatal@suse.com
- Run just autoreconf and intltoolize, to avoid double configure run
- Add deps for post/postun scriptlets
- Remove dep on lcms and depend on lcms2
* Tue Mar  7 2017 zaitor@opensuse.org
- Add README.lirc explicitly to doc packages, now needed due to
  rpm 4.13 no longer implicitly packages those files.
* Thu Jun 16 2016 dimstar@opensuse.org
- Update to version 1.3 (boo#985090):
  + Sort by creation date.
  + Enhancements in mouse less operation.
  + Rotation invariant duplication search.
  + Better zoom steps.
  + Easy access to working directory when copying ('.').
  + Updated documentation.
  + Speed improvements.
  + Stability improvements.
  + Many bugfixes.
- Enable source signature verification (geeqie.keyring plus
  corresponding .asc file).
* Mon Apr 18 2016 zaitor@opensuse.org
- Update to version 1.2.3:
  + Support for GTK+ 3.
  + Support for lcms2.
  + Basic support for lua scripting.
  + Several bugfixes.
- Replace pkgconfig(gtk+-2.0) for pkgconfig(gtk+-3.0) BuildReqiures
  following upstreams port to gtk3.
- Add disabled pkgconfig(lua-5.1) BuildRequires, configure does not
  find our lua.
- Replace libchamplain-devel for pkgconfig(champlain-0.12)
  BuildRequires, align with what configure looks for, but keep it
  disabled, since upstream deams libchamplain support experimental,
  and it's not the champlain we have in Tumbleweed.
- Add libtool BuildRequires and pass autogen.sh as the tarball is
  not bootstrapped.
- Update package descriptions.
- Update source and Url to new home.
- Drop geeqie-bigendian.patch and geeqie-1.1-fix-bashisms.patch:
  Fixed upstream.
- Remove conditionals for obsolete versions of openSUSE.
* Wed Dec 17 2014 zaitor@opensuse.org
- Rebase patch to match what upstream actually have commited.
* Tue Dec 16 2014 Led <ledest@gmail.com>
- Add geeqie-1.1-fix-bashisms.patch: Fix bashisms in geeqie-rotate
  script.
* Fri Dec 28 2012 dvaleev@suse.com
- Add geeqie-bigendian.patch: fix bigendian build.
* Sun Sep 16 2012 zaitor@opensuse.org
- Update to version 1.1:
  + Support for stereoscopic images.
  + input: side-by-side (JPS) and MPO format.
  + output: single image, anaglyph, SBS, mirror, SBS half size
    (3DTV).
  + Custom tiff loader - better handling of large tiff files.
  + Rewritten file grouping.
- Add libjpeg-devel and libtiff-devel BuildReqiuires, support jpg,
  and tiff loader.
- Add FIXME entry for champlain support.
- Pass enable-gps to configure, even if this is not taken into
  accout at the moment, libchamplain is not an active
  BuildRequires.
- Change configure switch --with-helpdir to --with-html dir,
  upstream does not support --with-helpdir anymore.
* Tue Sep 27 2011 vuntz@opensuse.org
- Initial package of this gqview fork (version 1.0).
